# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class StablecoinSystemTakeTxRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user': 'str',
        'auction_id': 'int',
        'ilk': 'str',
        'collateral_amount_upper_limit': 'str',
        'max_acceptable_price': 'str'
    }

    attribute_map = {
        'user': 'user',
        'auction_id': 'auctionId',
        'ilk': 'ilk',
        'collateral_amount_upper_limit': 'collateralAmountUpperLimit',
        'max_acceptable_price': 'maxAcceptablePrice'
    }

    def __init__(self, user=None, auction_id=None, ilk=None, collateral_amount_upper_limit=None, max_acceptable_price=None, local_vars_configuration=None):  # noqa: E501
        """StablecoinSystemTakeTxRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user = None
        self._auction_id = None
        self._ilk = None
        self._collateral_amount_upper_limit = None
        self._max_acceptable_price = None
        self.discriminator = None

        self.user = user
        self.auction_id = auction_id
        self.ilk = ilk
        self.collateral_amount_upper_limit = collateral_amount_upper_limit
        self.max_acceptable_price = max_acceptable_price

    @property
    def user(self):
        """Gets the user of this StablecoinSystemTakeTxRequest.  # noqa: E501

        Ethereum address of the user taking the auction.  # noqa: E501

        :return: The user of this StablecoinSystemTakeTxRequest.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this StablecoinSystemTakeTxRequest.

        Ethereum address of the user taking the auction.  # noqa: E501

        :param user: The user of this StablecoinSystemTakeTxRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                user is not None and not re.search(r'0x[a-fA-F0-9]{40}', user)):  # noqa: E501
            raise ValueError(r"Invalid value for `user`, must be a follow pattern or equal to `/0x[a-fA-F0-9]{40}/`")  # noqa: E501

        self._user = user

    @property
    def auction_id(self):
        """Gets the auction_id of this StablecoinSystemTakeTxRequest.  # noqa: E501

        The ID of the auction  # noqa: E501

        :return: The auction_id of this StablecoinSystemTakeTxRequest.  # noqa: E501
        :rtype: int
        """
        return self._auction_id

    @auction_id.setter
    def auction_id(self, auction_id):
        """Sets the auction_id of this StablecoinSystemTakeTxRequest.

        The ID of the auction  # noqa: E501

        :param auction_id: The auction_id of this StablecoinSystemTakeTxRequest.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and auction_id is None:  # noqa: E501
            raise ValueError("Invalid value for `auction_id`, must not be `None`")  # noqa: E501

        self._auction_id = auction_id

    @property
    def ilk(self):
        """Gets the ilk of this StablecoinSystemTakeTxRequest.  # noqa: E501

        Name of the ILK  # noqa: E501

        :return: The ilk of this StablecoinSystemTakeTxRequest.  # noqa: E501
        :rtype: str
        """
        return self._ilk

    @ilk.setter
    def ilk(self, ilk):
        """Sets the ilk of this StablecoinSystemTakeTxRequest.

        Name of the ILK  # noqa: E501

        :param ilk: The ilk of this StablecoinSystemTakeTxRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and ilk is None:  # noqa: E501
            raise ValueError("Invalid value for `ilk`, must not be `None`")  # noqa: E501

        self._ilk = ilk

    @property
    def collateral_amount_upper_limit(self):
        """Gets the collateral_amount_upper_limit of this StablecoinSystemTakeTxRequest.  # noqa: E501

        upper limit on the amount of collateral to buy [wad]  # noqa: E501

        :return: The collateral_amount_upper_limit of this StablecoinSystemTakeTxRequest.  # noqa: E501
        :rtype: str
        """
        return self._collateral_amount_upper_limit

    @collateral_amount_upper_limit.setter
    def collateral_amount_upper_limit(self, collateral_amount_upper_limit):
        """Sets the collateral_amount_upper_limit of this StablecoinSystemTakeTxRequest.

        upper limit on the amount of collateral to buy [wad]  # noqa: E501

        :param collateral_amount_upper_limit: The collateral_amount_upper_limit of this StablecoinSystemTakeTxRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and collateral_amount_upper_limit is None:  # noqa: E501
            raise ValueError("Invalid value for `collateral_amount_upper_limit`, must not be `None`")  # noqa: E501

        self._collateral_amount_upper_limit = collateral_amount_upper_limit

    @property
    def max_acceptable_price(self):
        """Gets the max_acceptable_price of this StablecoinSystemTakeTxRequest.  # noqa: E501

        Maximum acceptable price (ZAR / collateral) [ray]  # noqa: E501

        :return: The max_acceptable_price of this StablecoinSystemTakeTxRequest.  # noqa: E501
        :rtype: str
        """
        return self._max_acceptable_price

    @max_acceptable_price.setter
    def max_acceptable_price(self, max_acceptable_price):
        """Sets the max_acceptable_price of this StablecoinSystemTakeTxRequest.

        Maximum acceptable price (ZAR / collateral) [ray]  # noqa: E501

        :param max_acceptable_price: The max_acceptable_price of this StablecoinSystemTakeTxRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and max_acceptable_price is None:  # noqa: E501
            raise ValueError("Invalid value for `max_acceptable_price`, must not be `None`")  # noqa: E501

        self._max_acceptable_price = max_acceptable_price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StablecoinSystemTakeTxRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StablecoinSystemTakeTxRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class SwapRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'intent': 'str',
        'quote_id': 'str',
        'trade_type': 'str',
        '_in': 'str',
        'out': 'str',
        'amount': 'str'
    }

    attribute_map = {
        'intent': 'intent',
        'quote_id': 'quoteId',
        'trade_type': 'tradeType',
        '_in': 'in',
        'out': 'out',
        'amount': 'amount'
    }

    def __init__(self, intent=None, quote_id=None, trade_type=None, _in=None, out=None, amount=None, local_vars_configuration=None):  # noqa: E501
        """SwapRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._intent = None
        self._quote_id = None
        self._trade_type = None
        self.__in = None
        self._out = None
        self._amount = None
        self.discriminator = None

        self.intent = intent
        if quote_id is not None:
            self.quote_id = quote_id
        if trade_type is not None:
            self.trade_type = trade_type
        if _in is not None:
            self._in = _in
        if out is not None:
            self.out = out
        if amount is not None:
            self.amount = amount

    @property
    def intent(self):
        """Gets the intent of this SwapRequest.  # noqa: E501

        Intent to swap  # noqa: E501

        :return: The intent of this SwapRequest.  # noqa: E501
        :rtype: str
        """
        return self._intent

    @intent.setter
    def intent(self, intent):
        """Sets the intent of this SwapRequest.

        Intent to swap  # noqa: E501

        :param intent: The intent of this SwapRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and intent is None:  # noqa: E501
            raise ValueError("Invalid value for `intent`, must not be `None`")  # noqa: E501
        allowed_values = ["Swap", "Quote", "Preview"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and intent not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `intent` ({0}), must be one of {1}"  # noqa: E501
                .format(intent, allowed_values)
            )

        self._intent = intent

    @property
    def quote_id(self):
        """Gets the quote_id of this SwapRequest.  # noqa: E501

        Quote ID, required if intent is Swap  # noqa: E501

        :return: The quote_id of this SwapRequest.  # noqa: E501
        :rtype: str
        """
        return self._quote_id

    @quote_id.setter
    def quote_id(self, quote_id):
        """Sets the quote_id of this SwapRequest.

        Quote ID, required if intent is Swap  # noqa: E501

        :param quote_id: The quote_id of this SwapRequest.  # noqa: E501
        :type: str
        """

        self._quote_id = quote_id

    @property
    def trade_type(self):
        """Gets the trade_type of this SwapRequest.  # noqa: E501

        Trade type  # noqa: E501

        :return: The trade_type of this SwapRequest.  # noqa: E501
        :rtype: str
        """
        return self._trade_type

    @trade_type.setter
    def trade_type(self, trade_type):
        """Sets the trade_type of this SwapRequest.

        Trade type  # noqa: E501

        :param trade_type: The trade_type of this SwapRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["ExactInput", "ExactOutput"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and trade_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `trade_type` ({0}), must be one of {1}"  # noqa: E501
                .format(trade_type, allowed_values)
            )

        self._trade_type = trade_type

    @property
    def _in(self):
        """Gets the _in of this SwapRequest.  # noqa: E501

        Coin symbol to swap from  # noqa: E501

        :return: The _in of this SwapRequest.  # noqa: E501
        :rtype: str
        """
        return self.__in

    @_in.setter
    def _in(self, _in):
        """Sets the _in of this SwapRequest.

        Coin symbol to swap from  # noqa: E501

        :param _in: The _in of this SwapRequest.  # noqa: E501
        :type: str
        """

        self.__in = _in

    @property
    def out(self):
        """Gets the out of this SwapRequest.  # noqa: E501

        Coin symbol to swap to  # noqa: E501

        :return: The out of this SwapRequest.  # noqa: E501
        :rtype: str
        """
        return self._out

    @out.setter
    def out(self, out):
        """Sets the out of this SwapRequest.

        Coin symbol to swap to  # noqa: E501

        :param out: The out of this SwapRequest.  # noqa: E501
        :type: str
        """

        self._out = out

    @property
    def amount(self):
        """Gets the amount of this SwapRequest.  # noqa: E501

        Amount to swap  # noqa: E501

        :return: The amount of this SwapRequest.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this SwapRequest.

        Amount to swap  # noqa: E501

        :param amount: The amount of this SwapRequest.  # noqa: E501
        :type: str
        """

        self._amount = amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SwapRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SwapRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class KycRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'national_id': 'str',
        'date_of_birth': 'str',
        'card_number': 'str'
    }

    attribute_map = {
        'national_id': 'nationalId',
        'date_of_birth': 'dateOfBirth',
        'card_number': 'cardNumber'
    }

    def __init__(self, national_id=None, date_of_birth=None, card_number=None, local_vars_configuration=None):  # noqa: E501
        """KycRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._national_id = None
        self._date_of_birth = None
        self._card_number = None
        self.discriminator = None

        self.national_id = national_id
        self.date_of_birth = date_of_birth
        self.card_number = card_number

    @property
    def national_id(self):
        """Gets the national_id of this KycRequest.  # noqa: E501

        National ID  # noqa: E501

        :return: The national_id of this KycRequest.  # noqa: E501
        :rtype: str
        """
        return self._national_id

    @national_id.setter
    def national_id(self, national_id):
        """Sets the national_id of this KycRequest.

        National ID  # noqa: E501

        :param national_id: The national_id of this KycRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and national_id is None:  # noqa: E501
            raise ValueError("Invalid value for `national_id`, must not be `None`")  # noqa: E501

        self._national_id = national_id

    @property
    def date_of_birth(self):
        """Gets the date_of_birth of this KycRequest.  # noqa: E501

        Date of birth  # noqa: E501

        :return: The date_of_birth of this KycRequest.  # noqa: E501
        :rtype: str
        """
        return self._date_of_birth

    @date_of_birth.setter
    def date_of_birth(self, date_of_birth):
        """Sets the date_of_birth of this KycRequest.

        Date of birth  # noqa: E501

        :param date_of_birth: The date_of_birth of this KycRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and date_of_birth is None:  # noqa: E501
            raise ValueError("Invalid value for `date_of_birth`, must not be `None`")  # noqa: E501

        self._date_of_birth = date_of_birth

    @property
    def card_number(self):
        """Gets the card_number of this KycRequest.  # noqa: E501

        Card number  # noqa: E501

        :return: The card_number of this KycRequest.  # noqa: E501
        :rtype: str
        """
        return self._card_number

    @card_number.setter
    def card_number(self, card_number):
        """Sets the card_number of this KycRequest.

        Card number  # noqa: E501

        :param card_number: The card_number of this KycRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and card_number is None:  # noqa: E501
            raise ValueError("Invalid value for `card_number`, must not be `None`")  # noqa: E501

        self._card_number = card_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KycRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KycRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import zarban.service.openapi_client
from zarban.service.openapi_client.api.lending_pool_api import LendingPoolApi  # noqa: E501
from zarban.service.openapi_client.rest import ApiException


class TestLendingPoolApi(unittest.TestCase):
    """LendingPoolApi unit test stubs"""

    def setUp(self):
        self.api = zarban.service.openapi_client.api.lending_pool_api.LendingPoolApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_lending_pool_borrow(self):
        """Test case for create_lending_pool_borrow

        Borrow from lending pool  # noqa: E501
        """
        pass

    def test_create_lending_pool_deposit(self):
        """Test case for create_lending_pool_deposit

        Deposit to lending pool  # noqa: E501
        """
        pass

    def test_create_lending_pool_repay(self):
        """Test case for create_lending_pool_repay

        Repay to lending pool  # noqa: E501
        """
        pass

    def test_create_lending_pool_withdraw(self):
        """Test case for create_lending_pool_withdraw

        Withdraw from lending pool  # noqa: E501
        """
        pass

    def test_fetch_reserve_data_by_asset(self):
        """Test case for fetch_reserve_data_by_asset

        Fetch Reserve Data By Asset  # noqa: E501
        """
        pass

    def test_get_user_borrows(self):
        """Test case for get_user_borrows

        Get user borrows of lendingpool  # noqa: E501
        """
        pass

    def test_get_user_deposits(self):
        """Test case for get_user_deposits

        Get user deposits of Lendingpool  # noqa: E501
        """
        pass

    def test_set_lending_pool_asset_collateral(self):
        """Test case for set_lending_pool_asset_collateral

        Enable/Disable asset as collateral  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class WithdrawRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'time_created': 'Timestamp',
        'network': 'Network',
        'symbol': 'Symbol',
        'amount': 'str',
        'to': 'str',
        'comment': 'str',
        'status': 'str',
        'block_explorer_url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'time_created': 'timeCreated',
        'network': 'network',
        'symbol': 'symbol',
        'amount': 'amount',
        'to': 'to',
        'comment': 'comment',
        'status': 'status',
        'block_explorer_url': 'blockExplorerUrl'
    }

    def __init__(self, id=None, time_created=None, network=None, symbol=None, amount=None, to=None, comment=None, status=None, block_explorer_url=None, local_vars_configuration=None):  # noqa: E501
        """WithdrawRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._time_created = None
        self._network = None
        self._symbol = None
        self._amount = None
        self._to = None
        self._comment = None
        self._status = None
        self._block_explorer_url = None
        self.discriminator = None

        self.id = id
        self.time_created = time_created
        self.network = network
        self.symbol = symbol
        self.amount = amount
        self.to = to
        self.comment = comment
        self.status = status
        self.block_explorer_url = block_explorer_url

    @property
    def id(self):
        """Gets the id of this WithdrawRequest.  # noqa: E501


        :return: The id of this WithdrawRequest.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WithdrawRequest.


        :param id: The id of this WithdrawRequest.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def time_created(self):
        """Gets the time_created of this WithdrawRequest.  # noqa: E501


        :return: The time_created of this WithdrawRequest.  # noqa: E501
        :rtype: Timestamp
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """Sets the time_created of this WithdrawRequest.


        :param time_created: The time_created of this WithdrawRequest.  # noqa: E501
        :type: Timestamp
        """
        if self.local_vars_configuration.client_side_validation and time_created is None:  # noqa: E501
            raise ValueError("Invalid value for `time_created`, must not be `None`")  # noqa: E501

        self._time_created = time_created

    @property
    def network(self):
        """Gets the network of this WithdrawRequest.  # noqa: E501


        :return: The network of this WithdrawRequest.  # noqa: E501
        :rtype: Network
        """
        return self._network

    @network.setter
    def network(self, network):
        """Sets the network of this WithdrawRequest.


        :param network: The network of this WithdrawRequest.  # noqa: E501
        :type: Network
        """
        if self.local_vars_configuration.client_side_validation and network is None:  # noqa: E501
            raise ValueError("Invalid value for `network`, must not be `None`")  # noqa: E501

        self._network = network

    @property
    def symbol(self):
        """Gets the symbol of this WithdrawRequest.  # noqa: E501


        :return: The symbol of this WithdrawRequest.  # noqa: E501
        :rtype: Symbol
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this WithdrawRequest.


        :param symbol: The symbol of this WithdrawRequest.  # noqa: E501
        :type: Symbol
        """
        if self.local_vars_configuration.client_side_validation and symbol is None:  # noqa: E501
            raise ValueError("Invalid value for `symbol`, must not be `None`")  # noqa: E501

        self._symbol = symbol

    @property
    def amount(self):
        """Gets the amount of this WithdrawRequest.  # noqa: E501


        :return: The amount of this WithdrawRequest.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this WithdrawRequest.


        :param amount: The amount of this WithdrawRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def to(self):
        """Gets the to of this WithdrawRequest.  # noqa: E501


        :return: The to of this WithdrawRequest.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this WithdrawRequest.


        :param to: The to of this WithdrawRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and to is None:  # noqa: E501
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    @property
    def comment(self):
        """Gets the comment of this WithdrawRequest.  # noqa: E501


        :return: The comment of this WithdrawRequest.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this WithdrawRequest.


        :param comment: The comment of this WithdrawRequest.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def status(self):
        """Gets the status of this WithdrawRequest.  # noqa: E501


        :return: The status of this WithdrawRequest.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this WithdrawRequest.


        :param status: The status of this WithdrawRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["Pending", "Canceled", "Approved", "Rejected", "Proccessing", "Failed", "Sent", "AccountDebited", "AccountBalanceUnlocked", "Completed"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def block_explorer_url(self):
        """Gets the block_explorer_url of this WithdrawRequest.  # noqa: E501


        :return: The block_explorer_url of this WithdrawRequest.  # noqa: E501
        :rtype: str
        """
        return self._block_explorer_url

    @block_explorer_url.setter
    def block_explorer_url(self, block_explorer_url):
        """Sets the block_explorer_url of this WithdrawRequest.


        :param block_explorer_url: The block_explorer_url of this WithdrawRequest.  # noqa: E501
        :type: str
        """

        self._block_explorer_url = block_explorer_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WithdrawRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WithdrawRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class AccountLendingpoolSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'total_debt': 'dict(str, str)',
        'total_deposits': 'dict(str, str)',
        'total_collateral': 'dict(str, str)',
        'health_factor': 'str',
        'net_apy': 'str',
        'total_supply_apy': 'str',
        'total_borrow_apy': 'str',
        'available_to_borrow': 'dict(str, str)',
        'borrow_power_used': 'str',
        'current_liquidation_threshold': 'str',
        'loan_to_value': 'str'
    }

    attribute_map = {
        'total_debt': 'totalDebt',
        'total_deposits': 'totalDeposits',
        'total_collateral': 'totalCollateral',
        'health_factor': 'healthFactor',
        'net_apy': 'netApy',
        'total_supply_apy': 'totalSupplyApy',
        'total_borrow_apy': 'totalBorrowApy',
        'available_to_borrow': 'availableToBorrow',
        'borrow_power_used': 'borrowPowerUsed',
        'current_liquidation_threshold': 'currentLiquidationThreshold',
        'loan_to_value': 'loanToValue'
    }

    def __init__(self, total_debt=None, total_deposits=None, total_collateral=None, health_factor=None, net_apy=None, total_supply_apy=None, total_borrow_apy=None, available_to_borrow=None, borrow_power_used=None, current_liquidation_threshold=None, loan_to_value=None, local_vars_configuration=None):  # noqa: E501
        """AccountLendingpoolSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._total_debt = None
        self._total_deposits = None
        self._total_collateral = None
        self._health_factor = None
        self._net_apy = None
        self._total_supply_apy = None
        self._total_borrow_apy = None
        self._available_to_borrow = None
        self._borrow_power_used = None
        self._current_liquidation_threshold = None
        self._loan_to_value = None
        self.discriminator = None

        self.total_debt = total_debt
        self.total_deposits = total_deposits
        self.total_collateral = total_collateral
        self.health_factor = health_factor
        self.net_apy = net_apy
        self.total_supply_apy = total_supply_apy
        self.total_borrow_apy = total_borrow_apy
        self.available_to_borrow = available_to_borrow
        self.borrow_power_used = borrow_power_used
        self.current_liquidation_threshold = current_liquidation_threshold
        self.loan_to_value = loan_to_value

    @property
    def total_debt(self):
        """Gets the total_debt of this AccountLendingpoolSummary.  # noqa: E501


        :return: The total_debt of this AccountLendingpoolSummary.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._total_debt

    @total_debt.setter
    def total_debt(self, total_debt):
        """Sets the total_debt of this AccountLendingpoolSummary.


        :param total_debt: The total_debt of this AccountLendingpoolSummary.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and total_debt is None:  # noqa: E501
            raise ValueError("Invalid value for `total_debt`, must not be `None`")  # noqa: E501

        self._total_debt = total_debt

    @property
    def total_deposits(self):
        """Gets the total_deposits of this AccountLendingpoolSummary.  # noqa: E501


        :return: The total_deposits of this AccountLendingpoolSummary.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._total_deposits

    @total_deposits.setter
    def total_deposits(self, total_deposits):
        """Sets the total_deposits of this AccountLendingpoolSummary.


        :param total_deposits: The total_deposits of this AccountLendingpoolSummary.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and total_deposits is None:  # noqa: E501
            raise ValueError("Invalid value for `total_deposits`, must not be `None`")  # noqa: E501

        self._total_deposits = total_deposits

    @property
    def total_collateral(self):
        """Gets the total_collateral of this AccountLendingpoolSummary.  # noqa: E501


        :return: The total_collateral of this AccountLendingpoolSummary.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._total_collateral

    @total_collateral.setter
    def total_collateral(self, total_collateral):
        """Sets the total_collateral of this AccountLendingpoolSummary.


        :param total_collateral: The total_collateral of this AccountLendingpoolSummary.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and total_collateral is None:  # noqa: E501
            raise ValueError("Invalid value for `total_collateral`, must not be `None`")  # noqa: E501

        self._total_collateral = total_collateral

    @property
    def health_factor(self):
        """Gets the health_factor of this AccountLendingpoolSummary.  # noqa: E501

        Health factor in lending pool  # noqa: E501

        :return: The health_factor of this AccountLendingpoolSummary.  # noqa: E501
        :rtype: str
        """
        return self._health_factor

    @health_factor.setter
    def health_factor(self, health_factor):
        """Sets the health_factor of this AccountLendingpoolSummary.

        Health factor in lending pool  # noqa: E501

        :param health_factor: The health_factor of this AccountLendingpoolSummary.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and health_factor is None:  # noqa: E501
            raise ValueError("Invalid value for `health_factor`, must not be `None`")  # noqa: E501

        self._health_factor = health_factor

    @property
    def net_apy(self):
        """Gets the net_apy of this AccountLendingpoolSummary.  # noqa: E501

        Net annual percentage yield in lending pool  # noqa: E501

        :return: The net_apy of this AccountLendingpoolSummary.  # noqa: E501
        :rtype: str
        """
        return self._net_apy

    @net_apy.setter
    def net_apy(self, net_apy):
        """Sets the net_apy of this AccountLendingpoolSummary.

        Net annual percentage yield in lending pool  # noqa: E501

        :param net_apy: The net_apy of this AccountLendingpoolSummary.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and net_apy is None:  # noqa: E501
            raise ValueError("Invalid value for `net_apy`, must not be `None`")  # noqa: E501

        self._net_apy = net_apy

    @property
    def total_supply_apy(self):
        """Gets the total_supply_apy of this AccountLendingpoolSummary.  # noqa: E501

        Total supply rate in lending pool for account  # noqa: E501

        :return: The total_supply_apy of this AccountLendingpoolSummary.  # noqa: E501
        :rtype: str
        """
        return self._total_supply_apy

    @total_supply_apy.setter
    def total_supply_apy(self, total_supply_apy):
        """Sets the total_supply_apy of this AccountLendingpoolSummary.

        Total supply rate in lending pool for account  # noqa: E501

        :param total_supply_apy: The total_supply_apy of this AccountLendingpoolSummary.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and total_supply_apy is None:  # noqa: E501
            raise ValueError("Invalid value for `total_supply_apy`, must not be `None`")  # noqa: E501

        self._total_supply_apy = total_supply_apy

    @property
    def total_borrow_apy(self):
        """Gets the total_borrow_apy of this AccountLendingpoolSummary.  # noqa: E501

        Total borrow rate in lending pool for account  # noqa: E501

        :return: The total_borrow_apy of this AccountLendingpoolSummary.  # noqa: E501
        :rtype: str
        """
        return self._total_borrow_apy

    @total_borrow_apy.setter
    def total_borrow_apy(self, total_borrow_apy):
        """Sets the total_borrow_apy of this AccountLendingpoolSummary.

        Total borrow rate in lending pool for account  # noqa: E501

        :param total_borrow_apy: The total_borrow_apy of this AccountLendingpoolSummary.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and total_borrow_apy is None:  # noqa: E501
            raise ValueError("Invalid value for `total_borrow_apy`, must not be `None`")  # noqa: E501

        self._total_borrow_apy = total_borrow_apy

    @property
    def available_to_borrow(self):
        """Gets the available_to_borrow of this AccountLendingpoolSummary.  # noqa: E501


        :return: The available_to_borrow of this AccountLendingpoolSummary.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._available_to_borrow

    @available_to_borrow.setter
    def available_to_borrow(self, available_to_borrow):
        """Sets the available_to_borrow of this AccountLendingpoolSummary.


        :param available_to_borrow: The available_to_borrow of this AccountLendingpoolSummary.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and available_to_borrow is None:  # noqa: E501
            raise ValueError("Invalid value for `available_to_borrow`, must not be `None`")  # noqa: E501

        self._available_to_borrow = available_to_borrow

    @property
    def borrow_power_used(self):
        """Gets the borrow_power_used of this AccountLendingpoolSummary.  # noqa: E501

        Borrow power used in lending pool  # noqa: E501

        :return: The borrow_power_used of this AccountLendingpoolSummary.  # noqa: E501
        :rtype: str
        """
        return self._borrow_power_used

    @borrow_power_used.setter
    def borrow_power_used(self, borrow_power_used):
        """Sets the borrow_power_used of this AccountLendingpoolSummary.

        Borrow power used in lending pool  # noqa: E501

        :param borrow_power_used: The borrow_power_used of this AccountLendingpoolSummary.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and borrow_power_used is None:  # noqa: E501
            raise ValueError("Invalid value for `borrow_power_used`, must not be `None`")  # noqa: E501

        self._borrow_power_used = borrow_power_used

    @property
    def current_liquidation_threshold(self):
        """Gets the current_liquidation_threshold of this AccountLendingpoolSummary.  # noqa: E501

        Current liquidation threshold in lending pool  # noqa: E501

        :return: The current_liquidation_threshold of this AccountLendingpoolSummary.  # noqa: E501
        :rtype: str
        """
        return self._current_liquidation_threshold

    @current_liquidation_threshold.setter
    def current_liquidation_threshold(self, current_liquidation_threshold):
        """Sets the current_liquidation_threshold of this AccountLendingpoolSummary.

        Current liquidation threshold in lending pool  # noqa: E501

        :param current_liquidation_threshold: The current_liquidation_threshold of this AccountLendingpoolSummary.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and current_liquidation_threshold is None:  # noqa: E501
            raise ValueError("Invalid value for `current_liquidation_threshold`, must not be `None`")  # noqa: E501

        self._current_liquidation_threshold = current_liquidation_threshold

    @property
    def loan_to_value(self):
        """Gets the loan_to_value of this AccountLendingpoolSummary.  # noqa: E501

        Loan to value in lending pool  # noqa: E501

        :return: The loan_to_value of this AccountLendingpoolSummary.  # noqa: E501
        :rtype: str
        """
        return self._loan_to_value

    @loan_to_value.setter
    def loan_to_value(self, loan_to_value):
        """Sets the loan_to_value of this AccountLendingpoolSummary.

        Loan to value in lending pool  # noqa: E501

        :param loan_to_value: The loan_to_value of this AccountLendingpoolSummary.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and loan_to_value is None:  # noqa: E501
            raise ValueError("Invalid value for `loan_to_value`, must not be `None`")  # noqa: E501

        self._loan_to_value = loan_to_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountLendingpoolSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountLendingpoolSummary):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class DutchAmount(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'token': 'Token',
        'start_amount': 'dict(str, str)',
        'end_amount': 'dict(str, str)',
        'recipient': 'str'
    }

    attribute_map = {
        'token': 'token',
        'start_amount': 'startAmount',
        'end_amount': 'endAmount',
        'recipient': 'recipient'
    }

    def __init__(self, token=None, start_amount=None, end_amount=None, recipient=None, local_vars_configuration=None):  # noqa: E501
        """DutchAmount - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._token = None
        self._start_amount = None
        self._end_amount = None
        self._recipient = None
        self.discriminator = None

        self.token = token
        self.start_amount = start_amount
        self.end_amount = end_amount
        if recipient is not None:
            self.recipient = recipient

    @property
    def token(self):
        """Gets the token of this DutchAmount.  # noqa: E501


        :return: The token of this DutchAmount.  # noqa: E501
        :rtype: Token
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this DutchAmount.


        :param token: The token of this DutchAmount.  # noqa: E501
        :type: Token
        """
        if self.local_vars_configuration.client_side_validation and token is None:  # noqa: E501
            raise ValueError("Invalid value for `token`, must not be `None`")  # noqa: E501

        self._token = token

    @property
    def start_amount(self):
        """Gets the start_amount of this DutchAmount.  # noqa: E501


        :return: The start_amount of this DutchAmount.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._start_amount

    @start_amount.setter
    def start_amount(self, start_amount):
        """Sets the start_amount of this DutchAmount.


        :param start_amount: The start_amount of this DutchAmount.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and start_amount is None:  # noqa: E501
            raise ValueError("Invalid value for `start_amount`, must not be `None`")  # noqa: E501

        self._start_amount = start_amount

    @property
    def end_amount(self):
        """Gets the end_amount of this DutchAmount.  # noqa: E501


        :return: The end_amount of this DutchAmount.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._end_amount

    @end_amount.setter
    def end_amount(self, end_amount):
        """Sets the end_amount of this DutchAmount.


        :param end_amount: The end_amount of this DutchAmount.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and end_amount is None:  # noqa: E501
            raise ValueError("Invalid value for `end_amount`, must not be `None`")  # noqa: E501

        self._end_amount = end_amount

    @property
    def recipient(self):
        """Gets the recipient of this DutchAmount.  # noqa: E501


        :return: The recipient of this DutchAmount.  # noqa: E501
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """Sets the recipient of this DutchAmount.


        :param recipient: The recipient of this DutchAmount.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                recipient is not None and not re.search(r'^(0x)?[0-9a-fA-F]{40}$', recipient)):  # noqa: E501
            raise ValueError(r"Invalid value for `recipient`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]{40}$/`")  # noqa: E501

        self._recipient = recipient

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DutchAmount):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DutchAmount):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.models.loans_response_list import LoansResponseList  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException

class TestLoansResponseList(unittest.TestCase):
    """LoansResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test LoansResponseList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.wallet.openapi_client.models.loans_response_list.LoansResponseList()  # noqa: E501
        if include_optional :
            return LoansResponseList(
                data = [
                    zarban.wallet.openapi_client.models.loans_response.LoansResponse(
                        id = '0', 
                        user_id = 56, 
                        liquidation_price = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        collateral = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        collateralization_ratio = '1.5', 
                        loan_to_value = '0.5', 
                        debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        principal = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        scaled_debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        plan = zarban.wallet.openapi_client.models.loan_plan.LoanPlan(
                            name = 'ETH-A', 
                            min_collateralization_ratio = '1.5', 
                            acceptable_coins = [
                                zarban.wallet.openapi_client.models.coin.Coin(
                                    config = zarban.wallet.openapi_client.models.coin_config.CoinConfig(
                                        is_tradeable = True, 
                                        withdraw_fees = {"tron":"10"}, 
                                        min_withdrawal = {"tron":"10"}, 
                                        needs_memo = True, ), 
                                    symbol = 'USD', 
                                    name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                    logo_uri = '0', 
                                    depositable_networks = [
                                        zarban.wallet.openapi_client.models.network.Network(
                                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                            logo_uri = '0', )
                                        ], 
                                    withdrawable_networks = [
                                        zarban.wallet.openapi_client.models.network.Network(
                                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                            logo_uri = '0', )
                                        ], 
                                    content = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                                        title = '0', 
                                        text = '0', 
                                        bullets = [
                                            '0'
                                            ], ), )
                                ], 
                            fee = '0.05', 
                            max_debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                            min_debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                            loan_to_value_options = [
                                zarban.wallet.openapi_client.models.detailed_loan_to_value_options.DetailedLoanToValueOptions(
                                    name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                    value = '0.5', )
                                ], ), 
                        state = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                        updated_collateral_token_balance = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        updated_debt_token_balance = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        terms_and_conditions = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                            title = '0', 
                            text = '0', 
                            bullets = [
                                '0'
                                ], ), )
                    ]
            )
        else :
            return LoansResponseList(
                data = [
                    zarban.wallet.openapi_client.models.loans_response.LoansResponse(
                        id = '0', 
                        user_id = 56, 
                        liquidation_price = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        collateral = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        collateralization_ratio = '1.5', 
                        loan_to_value = '0.5', 
                        debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        principal = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        scaled_debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        plan = zarban.wallet.openapi_client.models.loan_plan.LoanPlan(
                            name = 'ETH-A', 
                            min_collateralization_ratio = '1.5', 
                            acceptable_coins = [
                                zarban.wallet.openapi_client.models.coin.Coin(
                                    config = zarban.wallet.openapi_client.models.coin_config.CoinConfig(
                                        is_tradeable = True, 
                                        withdraw_fees = {"tron":"10"}, 
                                        min_withdrawal = {"tron":"10"}, 
                                        needs_memo = True, ), 
                                    symbol = 'USD', 
                                    name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                    logo_uri = '0', 
                                    depositable_networks = [
                                        zarban.wallet.openapi_client.models.network.Network(
                                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                            logo_uri = '0', )
                                        ], 
                                    withdrawable_networks = [
                                        zarban.wallet.openapi_client.models.network.Network(
                                            name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                            logo_uri = '0', )
                                        ], 
                                    content = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                                        title = '0', 
                                        text = '0', 
                                        bullets = [
                                            '0'
                                            ], ), )
                                ], 
                            fee = '0.05', 
                            max_debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                            min_debt = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                            loan_to_value_options = [
                                zarban.wallet.openapi_client.models.detailed_loan_to_value_options.DetailedLoanToValueOptions(
                                    name = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                                    value = '0.5', )
                                ], ), 
                        state = {"en_US":"Zar Stablecoin","fa_IR":"استیبل کوین زر"}, 
                        updated_collateral_token_balance = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        updated_debt_token_balance = {"values":{"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}}, 
                        terms_and_conditions = zarban.wallet.openapi_client.models.bullet_content.BulletContent(
                            title = '0', 
                            text = '0', 
                            bullets = [
                                '0'
                                ], ), )
                    ],
        )

    def testLoansResponseList(self):
        """Test LoansResponseList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.api.user_api import UserApi  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException


class TestUserApi(unittest.TestCase):
    """UserApi unit test stubs"""

    def setUp(self):
        self.api = zarban.wallet.openapi_client.api.user_api.UserApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_confirm_kyc(self):
        """Test case for confirm_kyc

        Confirm KYC  # noqa: E501
        """
        pass

    def test_confirm_phone_number(self):
        """Test case for confirm_phone_number

        Confirm phone number  # noqa: E501
        """
        pass

    def test_create_child_user(self):
        """Test case for create_child_user

        create a child user  # noqa: E501
        """
        pass

    def test_get_user_profile(self):
        """Test case for get_user_profile

        Get profile  # noqa: E501
        """
        pass

    def test_submit_email_confirmation_otp(self):
        """Test case for submit_email_confirmation_otp

        Submit email confirmation OTP  # noqa: E501
        """
        pass

    def test_submit_kyc(self):
        """Test case for submit_kyc

        Submit KYC  # noqa: E501
        """
        pass

    def test_verify_phone_number(self):
        """Test case for verify_phone_number

        Verify phone number  # noqa: E501
        """
        pass

    def test_verify_user_email_address(self):
        """Test case for verify_user_email_address

        Verify email  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class FormattedReserveData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'underlying_asset': 'Token',
        'z_token_address': 'str',
        'variable_debt_token_address': 'str',
        'borrowing_enabled': 'bool',
        'is_active': 'bool',
        'is_frozen': 'bool',
        'usage_as_collateral_enabled': 'bool',
        'reserve_factor': 'str',
        'base_lt_vas_collateral': 'str',
        'reserve_liquidation_threshold': 'str',
        'reserve_liquidation_bonus': 'str',
        'utilization_rate': 'str',
        'total_debt': 'dict(str, str)',
        'total_liquidity': 'dict(str, str)',
        'available_liquidity': 'dict(str, str)',
        'supply_apy': 'str',
        'supply_apr': 'str',
        'variable_borrow_apy': 'str',
        'variable_borrow_apr': 'str',
        'price': 'dict(str, str)'
    }

    attribute_map = {
        'id': 'id',
        'underlying_asset': 'underlyingAsset',
        'z_token_address': 'zTokenAddress',
        'variable_debt_token_address': 'variableDebtTokenAddress',
        'borrowing_enabled': 'borrowingEnabled',
        'is_active': 'isActive',
        'is_frozen': 'isFrozen',
        'usage_as_collateral_enabled': 'usageAsCollateralEnabled',
        'reserve_factor': 'reserveFactor',
        'base_lt_vas_collateral': 'baseLTVasCollateral',
        'reserve_liquidation_threshold': 'reserveLiquidationThreshold',
        'reserve_liquidation_bonus': 'reserveLiquidationBonus',
        'utilization_rate': 'utilizationRate',
        'total_debt': 'totalDebt',
        'total_liquidity': 'totalLiquidity',
        'available_liquidity': 'availableLiquidity',
        'supply_apy': 'supplyAPY',
        'supply_apr': 'supplyAPR',
        'variable_borrow_apy': 'variableBorrowAPY',
        'variable_borrow_apr': 'variableBorrowAPR',
        'price': 'price'
    }

    def __init__(self, id=None, underlying_asset=None, z_token_address=None, variable_debt_token_address=None, borrowing_enabled=None, is_active=None, is_frozen=None, usage_as_collateral_enabled=None, reserve_factor=None, base_lt_vas_collateral=None, reserve_liquidation_threshold=None, reserve_liquidation_bonus=None, utilization_rate=None, total_debt=None, total_liquidity=None, available_liquidity=None, supply_apy=None, supply_apr=None, variable_borrow_apy=None, variable_borrow_apr=None, price=None, local_vars_configuration=None):  # noqa: E501
        """FormattedReserveData - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._underlying_asset = None
        self._z_token_address = None
        self._variable_debt_token_address = None
        self._borrowing_enabled = None
        self._is_active = None
        self._is_frozen = None
        self._usage_as_collateral_enabled = None
        self._reserve_factor = None
        self._base_lt_vas_collateral = None
        self._reserve_liquidation_threshold = None
        self._reserve_liquidation_bonus = None
        self._utilization_rate = None
        self._total_debt = None
        self._total_liquidity = None
        self._available_liquidity = None
        self._supply_apy = None
        self._supply_apr = None
        self._variable_borrow_apy = None
        self._variable_borrow_apr = None
        self._price = None
        self.discriminator = None

        self.id = id
        self.underlying_asset = underlying_asset
        self.z_token_address = z_token_address
        self.variable_debt_token_address = variable_debt_token_address
        self.borrowing_enabled = borrowing_enabled
        self.is_active = is_active
        self.is_frozen = is_frozen
        self.usage_as_collateral_enabled = usage_as_collateral_enabled
        self.reserve_factor = reserve_factor
        self.base_lt_vas_collateral = base_lt_vas_collateral
        self.reserve_liquidation_threshold = reserve_liquidation_threshold
        self.reserve_liquidation_bonus = reserve_liquidation_bonus
        self.utilization_rate = utilization_rate
        self.total_debt = total_debt
        self.total_liquidity = total_liquidity
        self.available_liquidity = available_liquidity
        self.supply_apy = supply_apy
        self.supply_apr = supply_apr
        self.variable_borrow_apy = variable_borrow_apy
        self.variable_borrow_apr = variable_borrow_apr
        self.price = price

    @property
    def id(self):
        """Gets the id of this FormattedReserveData.  # noqa: E501

        Identifier for the reserve data.  # noqa: E501

        :return: The id of this FormattedReserveData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FormattedReserveData.

        Identifier for the reserve data.  # noqa: E501

        :param id: The id of this FormattedReserveData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def underlying_asset(self):
        """Gets the underlying_asset of this FormattedReserveData.  # noqa: E501


        :return: The underlying_asset of this FormattedReserveData.  # noqa: E501
        :rtype: Token
        """
        return self._underlying_asset

    @underlying_asset.setter
    def underlying_asset(self, underlying_asset):
        """Sets the underlying_asset of this FormattedReserveData.


        :param underlying_asset: The underlying_asset of this FormattedReserveData.  # noqa: E501
        :type: Token
        """
        if self.local_vars_configuration.client_side_validation and underlying_asset is None:  # noqa: E501
            raise ValueError("Invalid value for `underlying_asset`, must not be `None`")  # noqa: E501

        self._underlying_asset = underlying_asset

    @property
    def z_token_address(self):
        """Gets the z_token_address of this FormattedReserveData.  # noqa: E501

        Address of the associated zToken contract in hexadecimal format.  # noqa: E501

        :return: The z_token_address of this FormattedReserveData.  # noqa: E501
        :rtype: str
        """
        return self._z_token_address

    @z_token_address.setter
    def z_token_address(self, z_token_address):
        """Sets the z_token_address of this FormattedReserveData.

        Address of the associated zToken contract in hexadecimal format.  # noqa: E501

        :param z_token_address: The z_token_address of this FormattedReserveData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and z_token_address is None:  # noqa: E501
            raise ValueError("Invalid value for `z_token_address`, must not be `None`")  # noqa: E501

        self._z_token_address = z_token_address

    @property
    def variable_debt_token_address(self):
        """Gets the variable_debt_token_address of this FormattedReserveData.  # noqa: E501

        Address of the associated variable debt token contract in hexadecimal format.  # noqa: E501

        :return: The variable_debt_token_address of this FormattedReserveData.  # noqa: E501
        :rtype: str
        """
        return self._variable_debt_token_address

    @variable_debt_token_address.setter
    def variable_debt_token_address(self, variable_debt_token_address):
        """Sets the variable_debt_token_address of this FormattedReserveData.

        Address of the associated variable debt token contract in hexadecimal format.  # noqa: E501

        :param variable_debt_token_address: The variable_debt_token_address of this FormattedReserveData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and variable_debt_token_address is None:  # noqa: E501
            raise ValueError("Invalid value for `variable_debt_token_address`, must not be `None`")  # noqa: E501

        self._variable_debt_token_address = variable_debt_token_address

    @property
    def borrowing_enabled(self):
        """Gets the borrowing_enabled of this FormattedReserveData.  # noqa: E501


        :return: The borrowing_enabled of this FormattedReserveData.  # noqa: E501
        :rtype: bool
        """
        return self._borrowing_enabled

    @borrowing_enabled.setter
    def borrowing_enabled(self, borrowing_enabled):
        """Sets the borrowing_enabled of this FormattedReserveData.


        :param borrowing_enabled: The borrowing_enabled of this FormattedReserveData.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and borrowing_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `borrowing_enabled`, must not be `None`")  # noqa: E501

        self._borrowing_enabled = borrowing_enabled

    @property
    def is_active(self):
        """Gets the is_active of this FormattedReserveData.  # noqa: E501


        :return: The is_active of this FormattedReserveData.  # noqa: E501
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """Sets the is_active of this FormattedReserveData.


        :param is_active: The is_active of this FormattedReserveData.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_active is None:  # noqa: E501
            raise ValueError("Invalid value for `is_active`, must not be `None`")  # noqa: E501

        self._is_active = is_active

    @property
    def is_frozen(self):
        """Gets the is_frozen of this FormattedReserveData.  # noqa: E501


        :return: The is_frozen of this FormattedReserveData.  # noqa: E501
        :rtype: bool
        """
        return self._is_frozen

    @is_frozen.setter
    def is_frozen(self, is_frozen):
        """Sets the is_frozen of this FormattedReserveData.


        :param is_frozen: The is_frozen of this FormattedReserveData.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_frozen is None:  # noqa: E501
            raise ValueError("Invalid value for `is_frozen`, must not be `None`")  # noqa: E501

        self._is_frozen = is_frozen

    @property
    def usage_as_collateral_enabled(self):
        """Gets the usage_as_collateral_enabled of this FormattedReserveData.  # noqa: E501


        :return: The usage_as_collateral_enabled of this FormattedReserveData.  # noqa: E501
        :rtype: bool
        """
        return self._usage_as_collateral_enabled

    @usage_as_collateral_enabled.setter
    def usage_as_collateral_enabled(self, usage_as_collateral_enabled):
        """Sets the usage_as_collateral_enabled of this FormattedReserveData.


        :param usage_as_collateral_enabled: The usage_as_collateral_enabled of this FormattedReserveData.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and usage_as_collateral_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `usage_as_collateral_enabled`, must not be `None`")  # noqa: E501

        self._usage_as_collateral_enabled = usage_as_collateral_enabled

    @property
    def reserve_factor(self):
        """Gets the reserve_factor of this FormattedReserveData.  # noqa: E501


        :return: The reserve_factor of this FormattedReserveData.  # noqa: E501
        :rtype: str
        """
        return self._reserve_factor

    @reserve_factor.setter
    def reserve_factor(self, reserve_factor):
        """Sets the reserve_factor of this FormattedReserveData.


        :param reserve_factor: The reserve_factor of this FormattedReserveData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and reserve_factor is None:  # noqa: E501
            raise ValueError("Invalid value for `reserve_factor`, must not be `None`")  # noqa: E501

        self._reserve_factor = reserve_factor

    @property
    def base_lt_vas_collateral(self):
        """Gets the base_lt_vas_collateral of this FormattedReserveData.  # noqa: E501


        :return: The base_lt_vas_collateral of this FormattedReserveData.  # noqa: E501
        :rtype: str
        """
        return self._base_lt_vas_collateral

    @base_lt_vas_collateral.setter
    def base_lt_vas_collateral(self, base_lt_vas_collateral):
        """Sets the base_lt_vas_collateral of this FormattedReserveData.


        :param base_lt_vas_collateral: The base_lt_vas_collateral of this FormattedReserveData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and base_lt_vas_collateral is None:  # noqa: E501
            raise ValueError("Invalid value for `base_lt_vas_collateral`, must not be `None`")  # noqa: E501

        self._base_lt_vas_collateral = base_lt_vas_collateral

    @property
    def reserve_liquidation_threshold(self):
        """Gets the reserve_liquidation_threshold of this FormattedReserveData.  # noqa: E501


        :return: The reserve_liquidation_threshold of this FormattedReserveData.  # noqa: E501
        :rtype: str
        """
        return self._reserve_liquidation_threshold

    @reserve_liquidation_threshold.setter
    def reserve_liquidation_threshold(self, reserve_liquidation_threshold):
        """Sets the reserve_liquidation_threshold of this FormattedReserveData.


        :param reserve_liquidation_threshold: The reserve_liquidation_threshold of this FormattedReserveData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and reserve_liquidation_threshold is None:  # noqa: E501
            raise ValueError("Invalid value for `reserve_liquidation_threshold`, must not be `None`")  # noqa: E501

        self._reserve_liquidation_threshold = reserve_liquidation_threshold

    @property
    def reserve_liquidation_bonus(self):
        """Gets the reserve_liquidation_bonus of this FormattedReserveData.  # noqa: E501


        :return: The reserve_liquidation_bonus of this FormattedReserveData.  # noqa: E501
        :rtype: str
        """
        return self._reserve_liquidation_bonus

    @reserve_liquidation_bonus.setter
    def reserve_liquidation_bonus(self, reserve_liquidation_bonus):
        """Sets the reserve_liquidation_bonus of this FormattedReserveData.


        :param reserve_liquidation_bonus: The reserve_liquidation_bonus of this FormattedReserveData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and reserve_liquidation_bonus is None:  # noqa: E501
            raise ValueError("Invalid value for `reserve_liquidation_bonus`, must not be `None`")  # noqa: E501

        self._reserve_liquidation_bonus = reserve_liquidation_bonus

    @property
    def utilization_rate(self):
        """Gets the utilization_rate of this FormattedReserveData.  # noqa: E501


        :return: The utilization_rate of this FormattedReserveData.  # noqa: E501
        :rtype: str
        """
        return self._utilization_rate

    @utilization_rate.setter
    def utilization_rate(self, utilization_rate):
        """Sets the utilization_rate of this FormattedReserveData.


        :param utilization_rate: The utilization_rate of this FormattedReserveData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and utilization_rate is None:  # noqa: E501
            raise ValueError("Invalid value for `utilization_rate`, must not be `None`")  # noqa: E501

        self._utilization_rate = utilization_rate

    @property
    def total_debt(self):
        """Gets the total_debt of this FormattedReserveData.  # noqa: E501


        :return: The total_debt of this FormattedReserveData.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._total_debt

    @total_debt.setter
    def total_debt(self, total_debt):
        """Sets the total_debt of this FormattedReserveData.


        :param total_debt: The total_debt of this FormattedReserveData.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and total_debt is None:  # noqa: E501
            raise ValueError("Invalid value for `total_debt`, must not be `None`")  # noqa: E501

        self._total_debt = total_debt

    @property
    def total_liquidity(self):
        """Gets the total_liquidity of this FormattedReserveData.  # noqa: E501


        :return: The total_liquidity of this FormattedReserveData.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._total_liquidity

    @total_liquidity.setter
    def total_liquidity(self, total_liquidity):
        """Sets the total_liquidity of this FormattedReserveData.


        :param total_liquidity: The total_liquidity of this FormattedReserveData.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and total_liquidity is None:  # noqa: E501
            raise ValueError("Invalid value for `total_liquidity`, must not be `None`")  # noqa: E501

        self._total_liquidity = total_liquidity

    @property
    def available_liquidity(self):
        """Gets the available_liquidity of this FormattedReserveData.  # noqa: E501


        :return: The available_liquidity of this FormattedReserveData.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._available_liquidity

    @available_liquidity.setter
    def available_liquidity(self, available_liquidity):
        """Sets the available_liquidity of this FormattedReserveData.


        :param available_liquidity: The available_liquidity of this FormattedReserveData.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and available_liquidity is None:  # noqa: E501
            raise ValueError("Invalid value for `available_liquidity`, must not be `None`")  # noqa: E501

        self._available_liquidity = available_liquidity

    @property
    def supply_apy(self):
        """Gets the supply_apy of this FormattedReserveData.  # noqa: E501


        :return: The supply_apy of this FormattedReserveData.  # noqa: E501
        :rtype: str
        """
        return self._supply_apy

    @supply_apy.setter
    def supply_apy(self, supply_apy):
        """Sets the supply_apy of this FormattedReserveData.


        :param supply_apy: The supply_apy of this FormattedReserveData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and supply_apy is None:  # noqa: E501
            raise ValueError("Invalid value for `supply_apy`, must not be `None`")  # noqa: E501

        self._supply_apy = supply_apy

    @property
    def supply_apr(self):
        """Gets the supply_apr of this FormattedReserveData.  # noqa: E501


        :return: The supply_apr of this FormattedReserveData.  # noqa: E501
        :rtype: str
        """
        return self._supply_apr

    @supply_apr.setter
    def supply_apr(self, supply_apr):
        """Sets the supply_apr of this FormattedReserveData.


        :param supply_apr: The supply_apr of this FormattedReserveData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and supply_apr is None:  # noqa: E501
            raise ValueError("Invalid value for `supply_apr`, must not be `None`")  # noqa: E501

        self._supply_apr = supply_apr

    @property
    def variable_borrow_apy(self):
        """Gets the variable_borrow_apy of this FormattedReserveData.  # noqa: E501


        :return: The variable_borrow_apy of this FormattedReserveData.  # noqa: E501
        :rtype: str
        """
        return self._variable_borrow_apy

    @variable_borrow_apy.setter
    def variable_borrow_apy(self, variable_borrow_apy):
        """Sets the variable_borrow_apy of this FormattedReserveData.


        :param variable_borrow_apy: The variable_borrow_apy of this FormattedReserveData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and variable_borrow_apy is None:  # noqa: E501
            raise ValueError("Invalid value for `variable_borrow_apy`, must not be `None`")  # noqa: E501

        self._variable_borrow_apy = variable_borrow_apy

    @property
    def variable_borrow_apr(self):
        """Gets the variable_borrow_apr of this FormattedReserveData.  # noqa: E501


        :return: The variable_borrow_apr of this FormattedReserveData.  # noqa: E501
        :rtype: str
        """
        return self._variable_borrow_apr

    @variable_borrow_apr.setter
    def variable_borrow_apr(self, variable_borrow_apr):
        """Sets the variable_borrow_apr of this FormattedReserveData.


        :param variable_borrow_apr: The variable_borrow_apr of this FormattedReserveData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and variable_borrow_apr is None:  # noqa: E501
            raise ValueError("Invalid value for `variable_borrow_apr`, must not be `None`")  # noqa: E501

        self._variable_borrow_apr = variable_borrow_apr

    @property
    def price(self):
        """Gets the price of this FormattedReserveData.  # noqa: E501


        :return: The price of this FormattedReserveData.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this FormattedReserveData.


        :param price: The price of this FormattedReserveData.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and price is None:  # noqa: E501
            raise ValueError("Invalid value for `price`, must not be `None`")  # noqa: E501

        self._price = price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FormattedReserveData):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FormattedReserveData):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.ilk import Ilk  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestIlk(unittest.TestCase):
    """Ilk unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Ilk
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.ilk.Ilk()  # noqa: E501
        if include_optional :
            return Ilk(
                name = '0', 
                symbol = 'USD', 
                minimum_collateralization_ratio = '0', 
                maximum_loan_to_value = '0', 
                liquidation_penalty = '0', 
                debt_ceiling = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                annual_stability_fee = '0', 
                dust_limit = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                next_price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                join = '0', 
                median = '0', 
                gem = '0', 
                clipper = '0', 
                pip = '0', 
                hole = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                dirt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                available_to_borrow = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}
            )
        else :
            return Ilk(
                name = '0',
                symbol = 'USD',
                minimum_collateralization_ratio = '0',
                maximum_loan_to_value = '0',
                liquidation_penalty = '0',
                debt_ceiling = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                debt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                annual_stability_fee = '0',
                dust_limit = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                next_price = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                join = '0',
                median = '0',
                gem = '0',
                clipper = '0',
                pip = '0',
                hole = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                dirt = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
                available_to_borrow = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"},
        )

    def testIlk(self):
        """Test Ilk"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from zarban.service.openapi_client.api.accounts_api import AccountsApi
from zarban.service.openapi_client.api.addresses_api import AddressesApi
from zarban.service.openapi_client.api.borrows_api import BorrowsApi
from zarban.service.openapi_client.api.collector_api import CollectorApi
from zarban.service.openapi_client.api.deposits_api import DepositsApi
from zarban.service.openapi_client.api.ilks_api import IlksApi
from zarban.service.openapi_client.api.lending_pool_api import LendingPoolApi
from zarban.service.openapi_client.api.logs_api import LogsApi
from zarban.service.openapi_client.api.orders_api import OrdersApi
from zarban.service.openapi_client.api.permit_api import PermitApi
from zarban.service.openapi_client.api.points_api import PointsApi
from zarban.service.openapi_client.api.prices_api import PricesApi
from zarban.service.openapi_client.api.stable_coin_system_api import StableCoinSystemApi
from zarban.service.openapi_client.api.staking_api import StakingApi
from zarban.service.openapi_client.api.swap_api import SwapApi
from zarban.service.openapi_client.api.vaults_api import VaultsApi
from zarban.service.openapi_client.api.websocket_api import WebsocketApi

# import ApiClient
from zarban.service.openapi_client.api_client import ApiClient
from zarban.service.openapi_client.configuration import Configuration
from zarban.service.openapi_client.exceptions import OpenApiException
from zarban.service.openapi_client.exceptions import ApiTypeError
from zarban.service.openapi_client.exceptions import ApiValueError
from zarban.service.openapi_client.exceptions import ApiKeyError
from zarban.service.openapi_client.exceptions import ApiException
# import models into sdk package
from zarban.service.openapi_client.models.account import Account
from zarban.service.openapi_client.models.account_lendingpool_summary import AccountLendingpoolSummary
from zarban.service.openapi_client.models.account_stablecoin_system_summary import AccountStablecoinSystemSummary
from zarban.service.openapi_client.models.account_staking_summary import AccountStakingSummary
from zarban.service.openapi_client.models.address import Address
from zarban.service.openapi_client.models.address_response import AddressResponse
from zarban.service.openapi_client.models.balance import Balance
from zarban.service.openapi_client.models.basic_event import BasicEvent
from zarban.service.openapi_client.models.chain_activity import ChainActivity
from zarban.service.openapi_client.models.chain_activity_step import ChainActivityStep
from zarban.service.openapi_client.models.chain_activity_step_data import ChainActivityStepData
from zarban.service.openapi_client.models.dutch_amount import DutchAmount
from zarban.service.openapi_client.models.eip712_sign_request import EIP712SignRequest
from zarban.service.openapi_client.models.error import Error
from zarban.service.openapi_client.models.error_message import ErrorMessage
from zarban.service.openapi_client.models.event_details_response import EventDetailsResponse
from zarban.service.openapi_client.models.event_domain import EventDomain
from zarban.service.openapi_client.models.event_name import EventName
from zarban.service.openapi_client.models.event_type import EventType
from zarban.service.openapi_client.models.extended_event import ExtendedEvent
from zarban.service.openapi_client.models.formatted_reserve_data import FormattedReserveData
from zarban.service.openapi_client.models.ilk import Ilk
from zarban.service.openapi_client.models.ilks_response import IlksResponse
from zarban.service.openapi_client.models.lendingpool_borrow import LendingpoolBorrow
from zarban.service.openapi_client.models.lendingpool_borrow_tx_request import LendingpoolBorrowTxRequest
from zarban.service.openapi_client.models.lendingpool_borrow_tx_response import LendingpoolBorrowTxResponse
from zarban.service.openapi_client.models.lendingpool_deposit import LendingpoolDeposit
from zarban.service.openapi_client.models.lendingpool_deposit_tx_request import LendingpoolDepositTxRequest
from zarban.service.openapi_client.models.lendingpool_deposit_tx_response import LendingpoolDepositTxResponse
from zarban.service.openapi_client.models.lendingpool_repay_tx_request import LendingpoolRepayTxRequest
from zarban.service.openapi_client.models.lendingpool_repay_tx_response import LendingpoolRepayTxResponse
from zarban.service.openapi_client.models.lendingpool_stats import LendingpoolStats
from zarban.service.openapi_client.models.lendingpool_tx_response import LendingpoolTxResponse
from zarban.service.openapi_client.models.lendingpool_use_asset_as_collateral_tx_request import LendingpoolUseAssetAsCollateralTxRequest
from zarban.service.openapi_client.models.lendingpool_use_asset_as_collateral_tx_response import LendingpoolUseAssetAsCollateralTxResponse
from zarban.service.openapi_client.models.lendingpool_withdraw_tx_request import LendingpoolWithdrawTxRequest
from zarban.service.openapi_client.models.lendingpool_withdraw_tx_response import LendingpoolWithdrawTxResponse
from zarban.service.openapi_client.models.log import Log
from zarban.service.openapi_client.models.method_parameters import MethodParameters
from zarban.service.openapi_client.models.order import Order
from zarban.service.openapi_client.models.order_info import OrderInfo
from zarban.service.openapi_client.models.order_response import OrderResponse
from zarban.service.openapi_client.models.order_type import OrderType
from zarban.service.openapi_client.models.permit_single import PermitSingle
from zarban.service.openapi_client.models.personal_sign_request import PersonalSignRequest
from zarban.service.openapi_client.models.prepared_tx import PreparedTx
from zarban.service.openapi_client.models.price import Price
from zarban.service.openapi_client.models.price_list_response import PriceListResponse
from zarban.service.openapi_client.models.quote_request import QuoteRequest
from zarban.service.openapi_client.models.quote_request_options import QuoteRequestOptions
from zarban.service.openapi_client.models.quote_response import QuoteResponse
from zarban.service.openapi_client.models.raw_dutch_amount import RawDutchAmount
from zarban.service.openapi_client.models.route_item import RouteItem
from zarban.service.openapi_client.models.scoreboard import Scoreboard
from zarban.service.openapi_client.models.scoreboard_item import ScoreboardItem
from zarban.service.openapi_client.models.stablecoin_system_bark_tx_request import StablecoinSystemBarkTxRequest
from zarban.service.openapi_client.models.stablecoin_system_create_vault_tx_request import StablecoinSystemCreateVaultTxRequest
from zarban.service.openapi_client.models.stablecoin_system_deposit_collateral_tx_request import StablecoinSystemDepositCollateralTxRequest
from zarban.service.openapi_client.models.stablecoin_system_gemexit_tx_request import StablecoinSystemGemexitTxRequest
from zarban.service.openapi_client.models.stablecoin_system_mint_zar_tx_request import StablecoinSystemMintZarTxRequest
from zarban.service.openapi_client.models.stablecoin_system_redo_tx_request import StablecoinSystemRedoTxRequest
from zarban.service.openapi_client.models.stablecoin_system_repay_zar_tx_request import StablecoinSystemRepayZarTxRequest
from zarban.service.openapi_client.models.stablecoin_system_stats import StablecoinSystemStats
from zarban.service.openapi_client.models.stablecoin_system_take_tx_request import StablecoinSystemTakeTxRequest
from zarban.service.openapi_client.models.stablecoin_system_withdraw_collateral_tx_request import StablecoinSystemWithdrawCollateralTxRequest
from zarban.service.openapi_client.models.stablecoin_system_zarexit_tx_request import StablecoinSystemZarexitTxRequest
from zarban.service.openapi_client.models.stablecoin_system_zarjoin_tx_request import StablecoinSystemZarjoinTxRequest
from zarban.service.openapi_client.models.stake_balance import StakeBalance
from zarban.service.openapi_client.models.stake_plan import StakePlan
from zarban.service.openapi_client.models.stake_plans_response import StakePlansResponse
from zarban.service.openapi_client.models.staking_collect_reward_tx_request import StakingCollectRewardTxRequest
from zarban.service.openapi_client.models.staking_collect_reward_tx_response import StakingCollectRewardTxResponse
from zarban.service.openapi_client.models.staking_stake_tx_request import StakingStakeTxRequest
from zarban.service.openapi_client.models.staking_stake_tx_response import StakingStakeTxResponse
from zarban.service.openapi_client.models.staking_withdraw_tx_request import StakingWithdrawTxRequest
from zarban.service.openapi_client.models.staking_withdraw_tx_response import StakingWithdrawTxResponse
from zarban.service.openapi_client.models.stats import Stats
from zarban.service.openapi_client.models.symbol import Symbol
from zarban.service.openapi_client.models.system_bad_debt import SystemBadDebt
from zarban.service.openapi_client.models.system_debt import SystemDebt
from zarban.service.openapi_client.models.system_debt_ceiling import SystemDebtCeiling
from zarban.service.openapi_client.models.system_surplus import SystemSurplus
from zarban.service.openapi_client.models.system_surplus_buffer import SystemSurplusBuffer
from zarban.service.openapi_client.models.system_surplus_lot_size import SystemSurplusLotSize
from zarban.service.openapi_client.models.time_range import TimeRange
from zarban.service.openapi_client.models.timestamp import Timestamp
from zarban.service.openapi_client.models.token import Token
from zarban.service.openapi_client.models.trade_type import TradeType
from zarban.service.openapi_client.models.type import Type
from zarban.service.openapi_client.models.typed_data import TypedData
from zarban.service.openapi_client.models.typed_data_domain import TypedDataDomain
from zarban.service.openapi_client.models.unclaimed_reward import UnclaimedReward
from zarban.service.openapi_client.models.update_order_request import UpdateOrderRequest
from zarban.service.openapi_client.models.user_borrows_response import UserBorrowsResponse
from zarban.service.openapi_client.models.user_deposits_response import UserDepositsResponse
from zarban.service.openapi_client.models.user_error import UserError
from zarban.service.openapi_client.models.user_stake import UserStake
from zarban.service.openapi_client.models.user_stakes_response import UserStakesResponse
from zarban.service.openapi_client.models.v3_pool_in_route import V3PoolInRoute
from zarban.service.openapi_client.models.vault import Vault
from zarban.service.openapi_client.models.vault_event import VaultEvent
from zarban.service.openapi_client.models.vault_event_extension import VaultEventExtension
from zarban.service.openapi_client.models.vault_event_item import VaultEventItem
from zarban.service.openapi_client.models.vault_events_response import VaultEventsResponse
from zarban.service.openapi_client.models.vaults_response import VaultsResponse
from zarban.service.openapi_client.models.wallet_balance import WalletBalance




# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class RedemptionRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'amount': 'str',
        'destination_card_number': 'str',
        'sms_otp': 'int'
    }

    attribute_map = {
        'amount': 'amount',
        'destination_card_number': 'destinationCardNumber',
        'sms_otp': 'SmsOtp'
    }

    def __init__(self, amount=None, destination_card_number=None, sms_otp=None, local_vars_configuration=None):  # noqa: E501
        """RedemptionRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._amount = None
        self._destination_card_number = None
        self._sms_otp = None
        self.discriminator = None

        self.amount = amount
        self.destination_card_number = destination_card_number
        self.sms_otp = sms_otp

    @property
    def amount(self):
        """Gets the amount of this RedemptionRequest.  # noqa: E501

        The amount to be redeemed in ZAR  # noqa: E501

        :return: The amount of this RedemptionRequest.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this RedemptionRequest.

        The amount to be redeemed in ZAR  # noqa: E501

        :param amount: The amount of this RedemptionRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def destination_card_number(self):
        """Gets the destination_card_number of this RedemptionRequest.  # noqa: E501

        The card number to which the redemption amount will be transferred  # noqa: E501

        :return: The destination_card_number of this RedemptionRequest.  # noqa: E501
        :rtype: str
        """
        return self._destination_card_number

    @destination_card_number.setter
    def destination_card_number(self, destination_card_number):
        """Sets the destination_card_number of this RedemptionRequest.

        The card number to which the redemption amount will be transferred  # noqa: E501

        :param destination_card_number: The destination_card_number of this RedemptionRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and destination_card_number is None:  # noqa: E501
            raise ValueError("Invalid value for `destination_card_number`, must not be `None`")  # noqa: E501

        self._destination_card_number = destination_card_number

    @property
    def sms_otp(self):
        """Gets the sms_otp of this RedemptionRequest.  # noqa: E501

        The SMS OTP code  # noqa: E501

        :return: The sms_otp of this RedemptionRequest.  # noqa: E501
        :rtype: int
        """
        return self._sms_otp

    @sms_otp.setter
    def sms_otp(self, sms_otp):
        """Sets the sms_otp of this RedemptionRequest.

        The SMS OTP code  # noqa: E501

        :param sms_otp: The sms_otp of this RedemptionRequest.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and sms_otp is None:  # noqa: E501
            raise ValueError("Invalid value for `sms_otp`, must not be `None`")  # noqa: E501

        self._sms_otp = sms_otp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RedemptionRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RedemptionRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.wallet.openapi_client.configuration import Configuration


class Payment(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'amount': 'str',
        'hash': 'str',
        'url': 'str',
        'sender_first_name': 'str',
        'text': 'str',
        'share_url': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'hash': 'hash',
        'url': 'url',
        'sender_first_name': 'senderFirstName',
        'text': 'text',
        'share_url': 'shareUrl'
    }

    def __init__(self, amount=None, hash=None, url=None, sender_first_name=None, text=None, share_url=None, local_vars_configuration=None):  # noqa: E501
        """Payment - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._amount = None
        self._hash = None
        self._url = None
        self._sender_first_name = None
        self._text = None
        self._share_url = None
        self.discriminator = None

        self.amount = amount
        self.hash = hash
        self.url = url
        self.sender_first_name = sender_first_name
        self.text = text
        self.share_url = share_url

    @property
    def amount(self):
        """Gets the amount of this Payment.  # noqa: E501

        Payment amount  # noqa: E501

        :return: The amount of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Payment.

        Payment amount  # noqa: E501

        :param amount: The amount of this Payment.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def hash(self):
        """Gets the hash of this Payment.  # noqa: E501

        Payment hash  # noqa: E501

        :return: The hash of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this Payment.

        Payment hash  # noqa: E501

        :param hash: The hash of this Payment.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and hash is None:  # noqa: E501
            raise ValueError("Invalid value for `hash`, must not be `None`")  # noqa: E501

        self._hash = hash

    @property
    def url(self):
        """Gets the url of this Payment.  # noqa: E501

        Payment URL  # noqa: E501

        :return: The url of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Payment.

        Payment URL  # noqa: E501

        :param url: The url of this Payment.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def sender_first_name(self):
        """Gets the sender_first_name of this Payment.  # noqa: E501

        Sender first name  # noqa: E501

        :return: The sender_first_name of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._sender_first_name

    @sender_first_name.setter
    def sender_first_name(self, sender_first_name):
        """Sets the sender_first_name of this Payment.

        Sender first name  # noqa: E501

        :param sender_first_name: The sender_first_name of this Payment.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and sender_first_name is None:  # noqa: E501
            raise ValueError("Invalid value for `sender_first_name`, must not be `None`")  # noqa: E501

        self._sender_first_name = sender_first_name

    @property
    def text(self):
        """Gets the text of this Payment.  # noqa: E501

        Payment text  # noqa: E501

        :return: The text of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this Payment.

        Payment text  # noqa: E501

        :param text: The text of this Payment.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and text is None:  # noqa: E501
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    @property
    def share_url(self):
        """Gets the share_url of this Payment.  # noqa: E501

        Share URL  # noqa: E501

        :return: The share_url of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._share_url

    @share_url.setter
    def share_url(self, share_url):
        """Sets the share_url of this Payment.

        Share URL  # noqa: E501

        :param share_url: The share_url of this Payment.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and share_url is None:  # noqa: E501
            raise ValueError("Invalid value for `share_url`, must not be `None`")  # noqa: E501

        self._share_url = share_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Payment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Payment):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class QuoteResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'OrderType',
        'trade_type': 'TradeType',
        'time': 'Timestamp',
        'amount': 'dict(str, str)',
        'quote': 'dict(str, str)',
        'quote_id': 'str',
        'gas_price': 'dict(str, str)',
        'gas_use_estimate': 'int',
        'gas_fee_estimate': 'dict(str, str)',
        'route_string': 'str',
        'method_parameters': 'MethodParameters',
        'route': 'list[RouteItem]',
        'order_info': 'OrderInfo',
        'encoded_order': 'str',
        'order_hash': 'str',
        'permit_data': 'TypedData'
    }

    attribute_map = {
        'type': 'type',
        'trade_type': 'tradeType',
        'time': 'time',
        'amount': 'amount',
        'quote': 'quote',
        'quote_id': 'quoteId',
        'gas_price': 'gasPrice',
        'gas_use_estimate': 'gasUseEstimate',
        'gas_fee_estimate': 'gasFeeEstimate',
        'route_string': 'routeString',
        'method_parameters': 'methodParameters',
        'route': 'route',
        'order_info': 'orderInfo',
        'encoded_order': 'encodedOrder',
        'order_hash': 'orderHash',
        'permit_data': 'permitData'
    }

    def __init__(self, type=None, trade_type=None, time=None, amount=None, quote=None, quote_id=None, gas_price=None, gas_use_estimate=None, gas_fee_estimate=None, route_string=None, method_parameters=None, route=None, order_info=None, encoded_order=None, order_hash=None, permit_data=None, local_vars_configuration=None):  # noqa: E501
        """QuoteResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._trade_type = None
        self._time = None
        self._amount = None
        self._quote = None
        self._quote_id = None
        self._gas_price = None
        self._gas_use_estimate = None
        self._gas_fee_estimate = None
        self._route_string = None
        self._method_parameters = None
        self._route = None
        self._order_info = None
        self._encoded_order = None
        self._order_hash = None
        self._permit_data = None
        self.discriminator = None

        self.type = type
        self.trade_type = trade_type
        self.time = time
        self.amount = amount
        self.quote = quote
        self.quote_id = quote_id
        self.gas_price = gas_price
        self.gas_use_estimate = gas_use_estimate
        self.gas_fee_estimate = gas_fee_estimate
        self.route_string = route_string
        if method_parameters is not None:
            self.method_parameters = method_parameters
        self.route = route
        if order_info is not None:
            self.order_info = order_info
        if encoded_order is not None:
            self.encoded_order = encoded_order
        if order_hash is not None:
            self.order_hash = order_hash
        if permit_data is not None:
            self.permit_data = permit_data

    @property
    def type(self):
        """Gets the type of this QuoteResponse.  # noqa: E501


        :return: The type of this QuoteResponse.  # noqa: E501
        :rtype: OrderType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this QuoteResponse.


        :param type: The type of this QuoteResponse.  # noqa: E501
        :type: OrderType
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def trade_type(self):
        """Gets the trade_type of this QuoteResponse.  # noqa: E501


        :return: The trade_type of this QuoteResponse.  # noqa: E501
        :rtype: TradeType
        """
        return self._trade_type

    @trade_type.setter
    def trade_type(self, trade_type):
        """Sets the trade_type of this QuoteResponse.


        :param trade_type: The trade_type of this QuoteResponse.  # noqa: E501
        :type: TradeType
        """
        if self.local_vars_configuration.client_side_validation and trade_type is None:  # noqa: E501
            raise ValueError("Invalid value for `trade_type`, must not be `None`")  # noqa: E501

        self._trade_type = trade_type

    @property
    def time(self):
        """Gets the time of this QuoteResponse.  # noqa: E501


        :return: The time of this QuoteResponse.  # noqa: E501
        :rtype: Timestamp
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this QuoteResponse.


        :param time: The time of this QuoteResponse.  # noqa: E501
        :type: Timestamp
        """
        if self.local_vars_configuration.client_side_validation and time is None:  # noqa: E501
            raise ValueError("Invalid value for `time`, must not be `None`")  # noqa: E501

        self._time = time

    @property
    def amount(self):
        """Gets the amount of this QuoteResponse.  # noqa: E501


        :return: The amount of this QuoteResponse.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this QuoteResponse.


        :param amount: The amount of this QuoteResponse.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def quote(self):
        """Gets the quote of this QuoteResponse.  # noqa: E501


        :return: The quote of this QuoteResponse.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._quote

    @quote.setter
    def quote(self, quote):
        """Sets the quote of this QuoteResponse.


        :param quote: The quote of this QuoteResponse.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and quote is None:  # noqa: E501
            raise ValueError("Invalid value for `quote`, must not be `None`")  # noqa: E501

        self._quote = quote

    @property
    def quote_id(self):
        """Gets the quote_id of this QuoteResponse.  # noqa: E501


        :return: The quote_id of this QuoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._quote_id

    @quote_id.setter
    def quote_id(self, quote_id):
        """Sets the quote_id of this QuoteResponse.


        :param quote_id: The quote_id of this QuoteResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and quote_id is None:  # noqa: E501
            raise ValueError("Invalid value for `quote_id`, must not be `None`")  # noqa: E501

        self._quote_id = quote_id

    @property
    def gas_price(self):
        """Gets the gas_price of this QuoteResponse.  # noqa: E501


        :return: The gas_price of this QuoteResponse.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._gas_price

    @gas_price.setter
    def gas_price(self, gas_price):
        """Sets the gas_price of this QuoteResponse.


        :param gas_price: The gas_price of this QuoteResponse.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and gas_price is None:  # noqa: E501
            raise ValueError("Invalid value for `gas_price`, must not be `None`")  # noqa: E501

        self._gas_price = gas_price

    @property
    def gas_use_estimate(self):
        """Gets the gas_use_estimate of this QuoteResponse.  # noqa: E501


        :return: The gas_use_estimate of this QuoteResponse.  # noqa: E501
        :rtype: int
        """
        return self._gas_use_estimate

    @gas_use_estimate.setter
    def gas_use_estimate(self, gas_use_estimate):
        """Sets the gas_use_estimate of this QuoteResponse.


        :param gas_use_estimate: The gas_use_estimate of this QuoteResponse.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and gas_use_estimate is None:  # noqa: E501
            raise ValueError("Invalid value for `gas_use_estimate`, must not be `None`")  # noqa: E501

        self._gas_use_estimate = gas_use_estimate

    @property
    def gas_fee_estimate(self):
        """Gets the gas_fee_estimate of this QuoteResponse.  # noqa: E501


        :return: The gas_fee_estimate of this QuoteResponse.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._gas_fee_estimate

    @gas_fee_estimate.setter
    def gas_fee_estimate(self, gas_fee_estimate):
        """Sets the gas_fee_estimate of this QuoteResponse.


        :param gas_fee_estimate: The gas_fee_estimate of this QuoteResponse.  # noqa: E501
        :type: dict(str, str)
        """
        if self.local_vars_configuration.client_side_validation and gas_fee_estimate is None:  # noqa: E501
            raise ValueError("Invalid value for `gas_fee_estimate`, must not be `None`")  # noqa: E501

        self._gas_fee_estimate = gas_fee_estimate

    @property
    def route_string(self):
        """Gets the route_string of this QuoteResponse.  # noqa: E501


        :return: The route_string of this QuoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._route_string

    @route_string.setter
    def route_string(self, route_string):
        """Sets the route_string of this QuoteResponse.


        :param route_string: The route_string of this QuoteResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and route_string is None:  # noqa: E501
            raise ValueError("Invalid value for `route_string`, must not be `None`")  # noqa: E501

        self._route_string = route_string

    @property
    def method_parameters(self):
        """Gets the method_parameters of this QuoteResponse.  # noqa: E501


        :return: The method_parameters of this QuoteResponse.  # noqa: E501
        :rtype: MethodParameters
        """
        return self._method_parameters

    @method_parameters.setter
    def method_parameters(self, method_parameters):
        """Sets the method_parameters of this QuoteResponse.


        :param method_parameters: The method_parameters of this QuoteResponse.  # noqa: E501
        :type: MethodParameters
        """

        self._method_parameters = method_parameters

    @property
    def route(self):
        """Gets the route of this QuoteResponse.  # noqa: E501


        :return: The route of this QuoteResponse.  # noqa: E501
        :rtype: list[RouteItem]
        """
        return self._route

    @route.setter
    def route(self, route):
        """Sets the route of this QuoteResponse.


        :param route: The route of this QuoteResponse.  # noqa: E501
        :type: list[RouteItem]
        """
        if self.local_vars_configuration.client_side_validation and route is None:  # noqa: E501
            raise ValueError("Invalid value for `route`, must not be `None`")  # noqa: E501

        self._route = route

    @property
    def order_info(self):
        """Gets the order_info of this QuoteResponse.  # noqa: E501


        :return: The order_info of this QuoteResponse.  # noqa: E501
        :rtype: OrderInfo
        """
        return self._order_info

    @order_info.setter
    def order_info(self, order_info):
        """Sets the order_info of this QuoteResponse.


        :param order_info: The order_info of this QuoteResponse.  # noqa: E501
        :type: OrderInfo
        """

        self._order_info = order_info

    @property
    def encoded_order(self):
        """Gets the encoded_order of this QuoteResponse.  # noqa: E501


        :return: The encoded_order of this QuoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._encoded_order

    @encoded_order.setter
    def encoded_order(self, encoded_order):
        """Sets the encoded_order of this QuoteResponse.


        :param encoded_order: The encoded_order of this QuoteResponse.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                encoded_order is not None and not re.search(r'^(0x)?[0-9a-fA-F]*$', encoded_order)):  # noqa: E501
            raise ValueError(r"Invalid value for `encoded_order`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]*$/`")  # noqa: E501

        self._encoded_order = encoded_order

    @property
    def order_hash(self):
        """Gets the order_hash of this QuoteResponse.  # noqa: E501


        :return: The order_hash of this QuoteResponse.  # noqa: E501
        :rtype: str
        """
        return self._order_hash

    @order_hash.setter
    def order_hash(self, order_hash):
        """Sets the order_hash of this QuoteResponse.


        :param order_hash: The order_hash of this QuoteResponse.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                order_hash is not None and not re.search(r'^(0x)?[0-9a-fA-F]{64}$', order_hash)):  # noqa: E501
            raise ValueError(r"Invalid value for `order_hash`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]{64}$/`")  # noqa: E501

        self._order_hash = order_hash

    @property
    def permit_data(self):
        """Gets the permit_data of this QuoteResponse.  # noqa: E501


        :return: The permit_data of this QuoteResponse.  # noqa: E501
        :rtype: TypedData
        """
        return self._permit_data

    @permit_data.setter
    def permit_data(self, permit_data):
        """Sets the permit_data of this QuoteResponse.


        :param permit_data: The permit_data of this QuoteResponse.  # noqa: E501
        :type: TypedData
        """

        self._permit_data = permit_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QuoteResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QuoteResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from zarban.service.openapi_client.configuration import Configuration


class QuoteRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'request_id': 'str',
        'type': 'OrderType',
        'trade_type': 'TradeType',
        'input_token': 'str',
        'output_token': 'str',
        'amount': 'str',
        'recipient': 'str',
        'options': 'QuoteRequestOptions'
    }

    attribute_map = {
        'request_id': 'requestId',
        'type': 'type',
        'trade_type': 'tradeType',
        'input_token': 'inputToken',
        'output_token': 'outputToken',
        'amount': 'amount',
        'recipient': 'recipient',
        'options': 'options'
    }

    def __init__(self, request_id=None, type=None, trade_type=None, input_token=None, output_token=None, amount=None, recipient=None, options=None, local_vars_configuration=None):  # noqa: E501
        """QuoteRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._request_id = None
        self._type = None
        self._trade_type = None
        self._input_token = None
        self._output_token = None
        self._amount = None
        self._recipient = None
        self._options = None
        self.discriminator = None

        if request_id is not None:
            self.request_id = request_id
        if type is not None:
            self.type = type
        self.trade_type = trade_type
        self.input_token = input_token
        self.output_token = output_token
        self.amount = amount
        self.recipient = recipient
        if options is not None:
            self.options = options

    @property
    def request_id(self):
        """Gets the request_id of this QuoteRequest.  # noqa: E501


        :return: The request_id of this QuoteRequest.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this QuoteRequest.


        :param request_id: The request_id of this QuoteRequest.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                request_id is not None and not re.search(r'^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[4][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}$', request_id)):  # noqa: E501
            raise ValueError(r"Invalid value for `request_id`, must be a follow pattern or equal to `/^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[4][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}$/`")  # noqa: E501

        self._request_id = request_id

    @property
    def type(self):
        """Gets the type of this QuoteRequest.  # noqa: E501


        :return: The type of this QuoteRequest.  # noqa: E501
        :rtype: OrderType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this QuoteRequest.


        :param type: The type of this QuoteRequest.  # noqa: E501
        :type: OrderType
        """

        self._type = type

    @property
    def trade_type(self):
        """Gets the trade_type of this QuoteRequest.  # noqa: E501


        :return: The trade_type of this QuoteRequest.  # noqa: E501
        :rtype: TradeType
        """
        return self._trade_type

    @trade_type.setter
    def trade_type(self, trade_type):
        """Sets the trade_type of this QuoteRequest.


        :param trade_type: The trade_type of this QuoteRequest.  # noqa: E501
        :type: TradeType
        """
        if self.local_vars_configuration.client_side_validation and trade_type is None:  # noqa: E501
            raise ValueError("Invalid value for `trade_type`, must not be `None`")  # noqa: E501

        self._trade_type = trade_type

    @property
    def input_token(self):
        """Gets the input_token of this QuoteRequest.  # noqa: E501


        :return: The input_token of this QuoteRequest.  # noqa: E501
        :rtype: str
        """
        return self._input_token

    @input_token.setter
    def input_token(self, input_token):
        """Sets the input_token of this QuoteRequest.


        :param input_token: The input_token of this QuoteRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and input_token is None:  # noqa: E501
            raise ValueError("Invalid value for `input_token`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                input_token is not None and not re.search(r'^(0x)?[0-9a-fA-F]{40}$', input_token)):  # noqa: E501
            raise ValueError(r"Invalid value for `input_token`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]{40}$/`")  # noqa: E501

        self._input_token = input_token

    @property
    def output_token(self):
        """Gets the output_token of this QuoteRequest.  # noqa: E501


        :return: The output_token of this QuoteRequest.  # noqa: E501
        :rtype: str
        """
        return self._output_token

    @output_token.setter
    def output_token(self, output_token):
        """Sets the output_token of this QuoteRequest.


        :param output_token: The output_token of this QuoteRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and output_token is None:  # noqa: E501
            raise ValueError("Invalid value for `output_token`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                output_token is not None and not re.search(r'^(0x)?[0-9a-fA-F]{40}$', output_token)):  # noqa: E501
            raise ValueError(r"Invalid value for `output_token`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]{40}$/`")  # noqa: E501

        self._output_token = output_token

    @property
    def amount(self):
        """Gets the amount of this QuoteRequest.  # noqa: E501


        :return: The amount of this QuoteRequest.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this QuoteRequest.


        :param amount: The amount of this QuoteRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def recipient(self):
        """Gets the recipient of this QuoteRequest.  # noqa: E501


        :return: The recipient of this QuoteRequest.  # noqa: E501
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """Sets the recipient of this QuoteRequest.


        :param recipient: The recipient of this QuoteRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and recipient is None:  # noqa: E501
            raise ValueError("Invalid value for `recipient`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                recipient is not None and not re.search(r'^(0x)?[0-9a-fA-F]{40}$', recipient)):  # noqa: E501
            raise ValueError(r"Invalid value for `recipient`, must be a follow pattern or equal to `/^(0x)?[0-9a-fA-F]{40}$/`")  # noqa: E501

        self._recipient = recipient

    @property
    def options(self):
        """Gets the options of this QuoteRequest.  # noqa: E501


        :return: The options of this QuoteRequest.  # noqa: E501
        :rtype: QuoteRequestOptions
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this QuoteRequest.


        :param options: The options of this QuoteRequest.  # noqa: E501
        :type: QuoteRequestOptions
        """

        self._options = options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QuoteRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QuoteRequest):
            return True

        return self.to_dict() != other.to_dict()
